@@ -1,5 +1,7 @@
 """
-Main interface for ssm service literal definitions.
+Type annotations for ssm service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/literals.html)
 
 Usage::
 
